import type { SdJwtVcSignOptions, SdJwtVcPresentOptions, SdJwtVcVerifyOptions, SdJwtVcPayload, SdJwtVcHeader } from './SdJwtVcOptions';
import type { AgentContext } from '../../agent';
import type { Query } from '../../storage/StorageService';
import type { SdJwtVcVerificationResult, DisclosureItem } from '@sd-jwt/core';
import { SdJwtVcRecord, SdJwtVcRepository } from './repository';
export { SdJwtVcVerificationResult, DisclosureItem };
export interface SdJwtVc<Header extends SdJwtVcHeader = SdJwtVcHeader, Payload extends SdJwtVcPayload = SdJwtVcPayload> {
    compact: string;
    header: Header;
    payload: Payload;
    prettyClaims: Payload;
}
/**
 * @internal
 */
export declare class SdJwtVcService {
    private sdJwtVcRepository;
    constructor(sdJwtVcRepository: SdJwtVcRepository);
    sign<Payload extends SdJwtVcPayload>(agentContext: AgentContext, options: SdJwtVcSignOptions<Payload>): Promise<{
        compact: string;
        prettyClaims: Payload;
        header: {
            readonly alg: import("../../crypto").JwaSignatureAlgorithm;
            readonly typ: "vc+sd-jwt";
            readonly kid: string;
        };
        payload: (Payload | undefined) & Payload & (Payload | (undefined & Payload));
    }>;
    fromCompact<Header extends SdJwtVcHeader = SdJwtVcHeader, Payload extends SdJwtVcPayload = SdJwtVcPayload>(compactSdJwtVc: string): SdJwtVc<Header, Payload>;
    present<Header extends SdJwtVcHeader = SdJwtVcHeader, Payload extends SdJwtVcPayload = SdJwtVcPayload>(agentContext: AgentContext, { compactSdJwtVc, presentationFrame, verifierMetadata }: SdJwtVcPresentOptions<Payload>): Promise<string>;
    verify<Header extends SdJwtVcHeader = SdJwtVcHeader, Payload extends SdJwtVcPayload = SdJwtVcPayload>(agentContext: AgentContext, { compactSdJwtVc, keyBinding, requiredClaimKeys }: SdJwtVcVerifyOptions): Promise<{
        verification: SdJwtVcVerificationResult;
        sdJwtVc: {
            payload: (Payload | undefined) & Payload & (Payload | (undefined & Payload));
            header: Header | (undefined & Header);
            compact: string;
            prettyClaims: Payload;
        };
    }>;
    store(agentContext: AgentContext, compactSdJwtVc: string): Promise<SdJwtVcRecord>;
    getById(agentContext: AgentContext, id: string): Promise<SdJwtVcRecord>;
    getAll(agentContext: AgentContext): Promise<Array<SdJwtVcRecord>>;
    findByQuery(agentContext: AgentContext, query: Query<SdJwtVcRecord>): Promise<Array<SdJwtVcRecord>>;
    deleteById(agentContext: AgentContext, id: string): Promise<void>;
    update(agentContext: AgentContext, sdJwtVcRecord: SdJwtVcRecord): Promise<void>;
    private resolveDidUrl;
    private get hasher();
    /**
     * @todo validate the JWT header (alg)
     */
    private signer;
    /**
     * @todo validate the JWT header (alg)
     */
    private verifier;
    private extractKeyFromIssuer;
    private parseIssuerFromCredential;
    private parseHolderBindingFromCredential;
    private extractKeyFromHolderBinding;
}
